@@ -93,8 +93,8 @@ void                        clipman_history_add_image                (ClipmanHis
                                                                       const GdkPixbuf          *image);
 GSList *                    clipman_history_get_list                 (ClipmanHistory           *history);
 guint                       clipman_history_get_max_texts_in_history (ClipmanHistory           *history);
-const ClipmanHistoryItem *  clipman_history_get_item_to_restore      (ClipmanHistory           *history);
-void                        clipman_history_set_item_to_restore      (ClipmanHistory           *history,
+const ClipmanHistoryItem *  clipman_history_get_image_to_restore     (ClipmanHistory           *history);
+void                        clipman_history_set_image_to_restore     (ClipmanHistory           *history,
                                                                       const ClipmanHistoryItem *item);
 void                        clipman_history_clear                    (ClipmanHistory           *history);
 void                        clipman_history_set_scale_factor         (ClipmanHistory           *history,
