@@ -402,7 +402,7 @@ static void
 clipman_history_paste_on_activate_changed (MyPlugin *plugin)
 {
   internal_paste_on_activate = xfconf_channel_get_uint (plugin->channel, "/tweaks/paste-on-activate", PASTE_INACTIVE)
-                               && GDK_IS_X11_DISPLAY (gdk_display_get_default ());
+                               && WINDOWING_IS_X11 ();
   clipman_history_copy_or_paste_on_activate (plugin, internal_paste_on_activate);
 
   g_signal_handlers_disconnect_by_func (plugin->entry, clipman_history_key_event, plugin);
@@ -430,7 +430,9 @@ clipman_history_dialog_init (MyPlugin *plugin)
   gtk_window_set_default_size (GTK_WINDOW (dialog), 350, 450);
 
 #if LIBXFCE4UI_CHECK_VERSION (4,15,1)
+#if !LIBXFCE4UI_CHECK_VERSION (4,19,3)
   xfce_titled_dialog_create_action_area (XFCE_TITLED_DIALOG (dialog));
+#endif
   button = xfce_titled_dialog_add_button (XFCE_TITLED_DIALOG (dialog), _("_Help"), GTK_RESPONSE_HELP);
 #else
   button = gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Help"), GTK_RESPONSE_HELP);
