@@ -91,7 +91,7 @@ prop_dialog_init (void)
 #else
   gtk_widget_hide(GTK_WIDGET (gtk_builder_get_object (builder, "show-qr-code")));
 #endif
-  if (!GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+  if (!WINDOWING_IS_X11 ())
     gtk_widget_hide (GTK_WIDGET (gtk_builder_get_object (builder, "persistent-selections")));
 
   /* paste-on-activate combobox */
@@ -102,7 +102,7 @@ prop_dialog_init (void)
   /* TRANSLATORS: Keyboard shortcut */
   gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combobox), _("Shift+Insert"));
   gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), 0);
-  if (!GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+  if (!WINDOWING_IS_X11 ())
     gtk_widget_hide (GTK_WIDGET (gtk_builder_get_object (builder, "hbox1")));
 
 #ifdef HAVE_QRENCODE
@@ -137,7 +137,7 @@ prop_dialog_init (void)
   gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combobox), _("shows actions"));
   gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combobox), _("hides actions"));
   gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), 0);
-  if (!GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+  if (!WINDOWING_IS_X11 ())
     gtk_widget_hide (GTK_WIDGET (gtk_builder_get_object (builder, "hbox-skip-action")));
 
   xfconf_g_property_bind (xfconf_channel, "/settings/enable-actions", G_TYPE_BOOLEAN,
